@@ -68,8 +68,10 @@ int  fileSignEncrypt(const char *inFileName,
 void parseList(char *recipients,char *nokeyrecipients);
 int checkRecipient(char *thisRecip);
 void printKeyInfo(char c, struct pkiKey *thisKey);
-void fileAskKey(char *nokeyrecipients);
+void fileAskKey(char *nokeyrecipients, int MODE);
 
+#define KEY_TOKENIZED   0
+#define KEY_HEX         1
 /* pgp4pine prefs.c */
 
 char *readPrefs(const char *searchKey, char *defaultVal);
