@@ -16,12 +16,12 @@ extern FILE *debugFile;
 extern int saveDebugFile;
 extern char debugLine[DEBUG_LINE_LENGTH];
 
-extern int prefsOverrideRecipients;
 extern int prefsVerboseOutput;
 extern int prefsExtraCRLFAtEnd;
 extern int prefsAddComment;
 extern int prefsCacheDecrypted;
 extern int prefsCacheKeyrings;
+extern int prefsFetchUnknownSigs;
 extern int addDashR;
 extern char prefsMyPager[MAX_COMMAND_LINE_LENGTH];
 extern char DecryptCacheName[MAX_COMMAND_LINE_LENGTH];
