@@ -14,12 +14,12 @@ FILE *debugFile;
 int saveDebugFile;
 char debugLine[DEBUG_LINE_LENGTH];
 
-int prefsOverrideRecipients;
 int prefsVerboseOutput;
 int prefsAddComment;
 int prefsExtraCRLFAtEnd;
 int prefsCacheDecrypted;
 int prefsCacheKeyrings;
+int prefsFetchUnknownSigs;
 int addDashR;
 char prefsMyPager[MAX_COMMAND_LINE_LENGTH];
 char DecryptCacheName[MAX_COMMAND_LINE_LENGTH];
