@@ -441,94 +441,109 @@ sub:q:2048:16:6360A0A5D47D03BA:1999-11-03::77::
 		pipe_pgp(appString,&inFile,&outFile);
 		if (outFile == NULL) return NULL;
 		while (!feof(outFile)) {
-			stillAlive();
-			/* using fgets() causes problems... */
-			cpString(outFile,buf,65530);
-			if (strlen(buf) < 1) break; /* we're done..... */
-			documentStatus(buf);
-			if (strchr(buf,':') != NULL) {
-				strncpy(keyType,getItem(buf,':',1),3);
-				lineType = 0;
-				if (strcmp(keyType,"sec") == 0) lineType = 1; /* secret line... */
-				if (strcmp(keyType,"pub") == 0) lineType = 2; /* public key     */
-				if (strcmp(keyType,"uid") == 0) lineType = 4; /* user id        */
+		  stillAlive();
+		  /* using fgets() causes problems... */
+		  cpString(outFile,buf,65530);
+		  if (strlen(buf) < 1) break; /* we're done..... */
+		  documentStatus(buf);
+		  if (strchr(buf,':') != NULL) {
+		    strncpy(keyType,getItem(buf,':',1),3);
+		    lineType = 0;
+		    /*
+		      The letter e in the second field of the colon delimited GnuPG
+		      output denotes that gpg asserts that the trust on this item
+		      has expired (perhaps as the result of an expired openPGP type
+		      0x13 or 0x18 signature packet).  If this line denotes a public
+		      key, GnuPG will not function with this key.  So, we should
+		      return with out adding it to the list.  We shouldn't check
+		      expiration ourselves because GnuPG is the final authority.
+		        - V. Alex Brennen, CryptNET FCAP [http://www.cryptnet.net/]
+		    	2001.02.13.01.13.47
+		    */
+		    strncpy(tmpString,getItem(buf,':',2),1);
+		    if (strcmp(tmpString,"e") == 0) lineType = -1; /* Line w/ expired trust */
+		    else if (strcmp(keyType,"sec") == 0) lineType = 1; /* secret line... */
+		    else if (strcmp(keyType,"pub") == 0) lineType = 2; /* public key     */
+		    else if (strcmp(keyType,"uid") == 0) lineType = 4; /* user id        */
 	
-				if (lineType == 1) inSec = 1;
-				if (lineType == 2) inSec = 0;
+		    if (lineType == 1) inSec = 1;
+		    else if (lineType == 2) inSec = 0;
 
-				switch (lineType) {
-				case 1:
-				case 2:
-					if (lineType == 2 && getSecretOnly) break;
-	                                myNewKey = (struct pkiKey *) myMalloc(sizeof(pkiKeyStruct));
-	                                if (firstKey == NULL) firstKey = myNewKey;
-	                                if (oldKey != NULL) oldKey->nextKey = myNewKey;
-	                                oldKey = myNewKey;
-		
-					/* next, key size... */
-					strncpy(tmpString,getItem(buf,':',3),KEY_SIZE_LENGTH);
-					strncpy(myNewKey->keySize,tmpString,KEY_SIZE_LENGTH);
+		    switch (lineType) {
+		    case 1:
+		    case 2:
+			if (lineType == 2 && getSecretOnly) break;
+
+			myNewKey = (struct pkiKey *) myMalloc(sizeof(pkiKeyStruct));
+			if (firstKey == NULL) firstKey = myNewKey;
+			if (oldKey != NULL) oldKey->nextKey = myNewKey;
+			oldKey = myNewKey;
+
+			/* next, key size... */
+			strncpy(tmpString,getItem(buf,':',3),KEY_SIZE_LENGTH);
+			strncpy(myNewKey->keySize,tmpString,KEY_SIZE_LENGTH);
 	
-					/* next, GPG key type... */
-					strncpy(tmpString,getItem(buf,':',4),KEY_TYPE_LENGTH);
-					strcpy(myNewKey->keyType,"Unknown"); /* STRCPY SAFE */
-					if (strcmp(tmpString,"1") == 0) strcpy(myNewKey->keyType,"RSA");      /* STRCPY SAFE */
-					if (strcmp(tmpString,"16") == 0) strcpy(myNewKey->keyType,"ElGamal"); /* STRCPY SAFE */
-					if (strcmp(tmpString,"17") == 0) strcpy(myNewKey->keyType,"DSA");     /* STRCPY SAFE */
-					if (strcmp(tmpString,"20") == 0) strcpy(myNewKey->keyType,"ElGamal"); /* STRCPY SAFE */
-				
-					/* keyID */
-					strncpy(tmpString,getItem(buf,':',5),KEY_ID_LENGTH);
-					/*	Any GPG keyid starting w/ a letter	      */
-				        /*	must be prefixed with '0' to work.	      */
-				        /*						      */
-				        /*	As the additional '0' does no harm	      */
-				        /*	in case of the keyid starting w/ a	      */
-				        /*	digit, add it anywhere. 		      */
-				        /*						      */
-				        /*	Keyid len is 64bits, which makes for	      */
-				        /*	16 digits, size of array is big enough.       */
-				        /*						      */
-					sprintf(myNewKey->keyID,"0%s",tmpString); /* SPRINTF SAFE */
+			/* next, GPG key type... */
+			strncpy(tmpString,getItem(buf,':',4),KEY_TYPE_LENGTH);
+			strcpy(myNewKey->keyType,"Unknown"); /* STRCPY SAFE */
+			if (strcmp(tmpString,"1") == 0) strcpy(myNewKey->keyType,"RSA");      /* STRCPY SAFE */
+			if (strcmp(tmpString,"16") == 0) strcpy(myNewKey->keyType,"ElGamal"); /* STRCPY SAFE */
+			if (strcmp(tmpString,"17") == 0) strcpy(myNewKey->keyType,"DSA");     /* STRCPY SAFE */
+			if (strcmp(tmpString,"20") == 0) strcpy(myNewKey->keyType,"ElGamal"); /* STRCPY SAFE */
+	
+			/* keyID */
+			strncpy(tmpString,getItem(buf,':',5),KEY_ID_LENGTH);
+			/*	Any GPG keyid starting w/ a letter	      */
+			/*	must be prefixed with '0' to work.	      */
+			/*						      */
+			/*	As the additional '0' does no harm	      */
+			/*	in case of the keyid starting w/ a	      */
+			/*	digit, add it anywhere. 		      */
+			/*						      */
+			/*	Keyid len is 64bits, which makes for	      */
+			/*	16 digits, size of array is big enough.       */
+			/*						      */
+			sprintf(myNewKey->keyID,"0%s",tmpString); /* SPRINTF SAFE */
 
-					/* finally, user name */
-					strncpy(tmpString,getItem(buf,':',10),EMAIL_ADDRESS_MAX_LENGTH);
-					UnescapeString(tmpString);	/* The ':' is quoted with '\x3a', so unescape */
-					strncpy(myNewKey->displayName,extractDisplayName(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
-					strncpy(myNewKey->emailAddress,extractEmailAddress(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
-					break;
-				case 4:
-					if (!getSecretOnly || inSec) {
-						/* If we're loading only secret keys, I only need one name
-						   If we're loading all keys, I need all names... */
-						if (getSecretOnly) {
-							/* If loading only secret keys, and already have a name, break. */
-							if (strlen(myNewKey->displayName) > 2) break;
-						} else {
-							/* If loading all keys, need all names, if last key has a name already, make new key... */
-							if (strlen(myNewKey->displayName) > 2) {
-				                                myNewKey = (struct pkiKey *) myMalloc(sizeof(pkiKeyStruct));
-				                                if (firstKey == NULL) firstKey = myNewKey;
-				                                if (oldKey != NULL) oldKey->nextKey = myNewKey;
-								strcpy(myNewKey->keyID,oldKey->keyID);     /* STRCPY SAFE */
-								strcpy(myNewKey->keySize,oldKey->keySize); /* STRCPY SAFE */
-								strcpy(myNewKey->keyType,oldKey->keyType); /* STRCPY SAFE */
-				                                oldKey = myNewKey;
-							}
-						}
-
-						/* finally, user name */
-						strncpy(tmpString,getItem(buf,':',10),EMAIL_ADDRESS_MAX_LENGTH);
-						strncpy(myNewKey->displayName,extractDisplayName(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
-						strncpy(myNewKey->emailAddress,extractEmailAddress(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
+			/* finally, user name */
+			strncpy(tmpString,getItem(buf,':',10),EMAIL_ADDRESS_MAX_LENGTH);
+			UnescapeString(tmpString);	/* The ':' is quoted with '\x3a', so unescape */
+			strncpy(myNewKey->displayName,extractDisplayName(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
+			strncpy(myNewKey->emailAddress,extractEmailAddress(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
+			break;
+		    case 4:
+			if (!getSecretOnly || inSec) {
+				/* If we're loading only secret keys, I only need one name
+				   If we're loading all keys, I need all names... */
+				if (getSecretOnly) {
+					/* If loading only secret keys, and already have a name, break. */
+					if (strlen(myNewKey->displayName) > 2) break;
+				} else {
+					/* If loading all keys, need all names, if last key has a name already, make new key... */
+					if (strlen(myNewKey->displayName) > 2) {
+					myNewKey = (struct pkiKey *) myMalloc(sizeof(pkiKeyStruct));
+					if (firstKey == NULL) firstKey = myNewKey;
+					if (oldKey != NULL) oldKey->nextKey = myNewKey;
+					  strcpy(myNewKey->keyID,oldKey->keyID);     /* STRCPY SAFE */
+					  strcpy(myNewKey->keySize,oldKey->keySize); /* STRCPY SAFE */
+					  strcpy(myNewKey->keyType,oldKey->keyType); /* STRCPY SAFE */
+					  oldKey = myNewKey;
 					}
-					break;
 				}
+
+				/* finally, user name */
+				strncpy(tmpString,getItem(buf,':',10),EMAIL_ADDRESS_MAX_LENGTH);
+				strncpy(myNewKey->displayName,extractDisplayName(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
+				strncpy(myNewKey->emailAddress,extractEmailAddress(tmpString),EMAIL_ADDRESS_MAX_LENGTH);
 			}
-		}
+		    default:
+			break;
+		    }   /* switch lineType*/
+		  }     /* If strchr */
+		}       /* while */
 		fclose(outFile);
 		break;
-	}
+	} /* switch pgpVersion */
 	return firstKey; /* Return pointer to keyring */
 }
 
