@@ -13,73 +13,73 @@
 /* ------------------------------------------------------------ */
 void fileVerifyDecryptMenu(char *inFile,char *outFile)
 {
-	FILE *fin;
-	int  fertig=0,i=0;
-	char readline[CONSOLE_IO_LINE_LENGTH];
-	int  c;  /* must be int, not char, to store EOF is char is 1 Byte. By Thorsten Wittmann. */
-	
-	if ((fin=fopen(inFile,"r"))==NULL)
-	{
-	  printf("Error opening Message !!\n");
-	  documentStatus("Error in fileVerifyDecryptMenu(): Unable to open input file\n"); 
-	}
-	else
-	do {
-	  fertig=0;
-	  while (!fertig)
-	  {
-	    if ((c=getc(fin))==EOF)
-	    {
-	      outFile=inFile; /* this usually is not 
-	      			 executed, EOF breaks directly */
-	      return;
-	    } 
-	    else if ((readline[i++]=c) == '\n')
-	    {
-	      readline[i]='\0';
-	      fertig=1;
-	    } 
-	  }
-	  fertig=0;
-	  
-	  if (strncmp("-----BEGIN PGP SIGNED",readline,20)==0)
-	  {
-	    /* got signed message */
-	    fclose(fin);
-	    fileVerify(inFile,outFile);
-	    fertig=1;
-	  } 
-	  else if (strncmp("-----BEGIN PGP",readline,14)==0)
-	  {
-	    /* got another type of PGP message (encrypted, keys ...) */
-	    fclose(fin);
-	    fileDecrypt(inFile,outFile);
-	    waitForReturn();
-	    fertig=1;
-	  }
-	  else
-	    i=0; /* Got waste line, reset i */
-	} while (!fertig);
+ FILE *fin;
+ int  fertig=0,i=0;
+ char readline[CONSOLE_IO_LINE_LENGTH];
+ int  c;  /* must be int, not char, to store EOF is char is 1 Byte. By Thorsten Wittmann. */
+
+ if ((fin=fopen(inFile,"r"))==NULL)
+ {
+   printf("Error opening Message !!\n");
+   documentStatus("Error in fileVerifyDecryptMenu(): Unable to open input file\n"); 
+ }
+ else
+ do {
+   fertig=0;
+   while (!fertig)
+   {
+     if ((c=getc(fin))==EOF)
+     {
+       outFile=inFile; /* this usually is not 
+ 			  executed, EOF breaks directly */
+       return;
+     } 
+     else if ((readline[i++]=c) == '\n')
+     {
+       readline[i]='\0';
+       fertig=1;
+     } 
+   }
+   fertig=0;
+   
+   if (strncmp("-----BEGIN PGP SIGNED",readline,20)==0)
+   {
+     /* got signed message */
+     fclose(fin);
+     while (fileVerify(inFile,outFile) > 0); /* =1: Repeat */
+     fertig=1;
+   } 
+   else if (strncmp("-----BEGIN PGP",readline,14)==0)
+   {
+     /* got another type of PGP message (encrypted, keys ...) */
+     fclose(fin);
+     fileDecrypt(inFile,outFile);
+     waitForReturn();
+     fertig=1;
+   }
+   else
+     i=0; /* Got waste line, reset i */
+ } while (!fertig);
 }
 void fileVerifyMenu(const char *inFile,const char *outFile)
 {
-	/* inFile and outFile are a) just passed to fileVerifyDecrypt, and
-	   b) should already be copied into inFile, outFile in main.c:main()
-	   so they should be (safe) pointers... */
-	printf("\nVerify file\n\n");
-	fileVerify(inFile,outFile); 	/* pki.c */
-	return;
+  /* inFile and outFile are a) just passed to fileVerifyDecrypt, and
+     b) should already be copied into inFile, outFile in main.c:main()
+     so they should be (safe) pointers... */
+  printf("\nVerify file\n\n");
+  fileVerify(inFile,outFile);	  /* pki.c */
+  return;
 }
 
 void fileDecryptMenu(const char *inFile,const char *outFile)
 {
-	/* inFile and outFile are a) just passed to fileVerifyDecrypt, and
-	   b) should already be copied into inFile, outFile in main.c:main()
-	   so they should be (safe) pointers... */
-	printf("\nDecrypt file\n\n");
-	fileDecrypt(inFile,outFile);	/* pki.c */
-	waitForReturn();
-	return;
+  /* inFile and outFile are a) just passed to fileVerifyDecrypt, and
+     b) should already be copied into inFile, outFile in main.c:main()
+     so they should be (safe) pointers... */
+  printf("\nDecrypt file\n\n");
+  fileDecrypt(inFile,outFile);    /* pki.c */
+  waitForReturn();
+  return;
 }
 
 /* There are lots of combinations for do-sign and do-encrypt values, and if recipients are already present or not.
@@ -144,7 +144,7 @@ int menu_noyes (int *sign, int *encrypt, int unknownkeys) /* Menu 1*/
       {
       	  case 'a': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
     	  case 'b': action= 2;				documentStatus("Selection: Ask\n");  break;
-	  case 'c': action= 3;				documentStatus("Selectoin: Shell\n"); break;
+	  case 'c': action= 3;				documentStatus("Selection: Shell\n"); break;
     	  default : action=-1;				documentStatus("Selection: quit\n");
       }
     }
@@ -394,7 +394,7 @@ int fileSignEncryptMenu(const char *inFile, char *outFile, char *recipients)
      printf("Your preset is: ");
      switch (signFile*3 + encryptFile)	/* Ask two variables in one switch.. */
      {
-       case -4: printf("do nothing\n");		break;   /* S-E- */
+       case -4: printf("do nothing\n");		  break;   /* S-E- */
        case -3: printf("don't sign\n"); 	  break;   /* S-E? */
        case -2: printf("encrypt and no sign\n");  break;   /* S-E+ */
        case -1: printf("don't encrypt\n");	  break;   /* S?E- */
@@ -407,116 +407,118 @@ int fileSignEncryptMenu(const char *inFile, char *outFile, char *recipients)
    }
 
    do {	
-        if ((signFile == -1) && (encryptFile == -1)) /* Do nothing at all */
-   	/* Return 0 as a sign to send unmodified (message is still in infile, not tmpfile) */
-	  return 0;
+     if ((signFile == -1) && (encryptFile == -1)) /* Do nothing at all */
+      /* Return 0 as a sign to send unmodified (message is still in infile, not tmpfile) */
+	return 0;
 
-	/* initialize recipients lists */
+      /* initialize recipients lists */
 
-	if (strlen(recipients) < 3 || prefsOverrideRecipients == 1) 
-	{
-		strcpy(recipients,"");
-		printf("Please enter the recipients below. Type . by itself on it's own line to end.\n");
-		do {
-			scanf("%s",tmpList);
-			/* Using fgets seems to break the strcmp() below... */
-		     /* fgets(tmpList, EMAIL_ADDRESS_MAX_LENGTH, stdin); */
-			strcat(recipients,tmpList);
-			strcat(recipients," ");
-		} while (strcmp(tmpList,"."));
-	}
+     if (strlen(recipients) < 3)	/* No recipients, e.g. sending to a newsgroup: */ 
+	encryptFile=-1;		/* Do not encrypt, maybe sign */
 
-	strcpy(keyrecipients,recipients); 
+     strcpy(keyrecipients,recipients);
 /* Leave recipients untouched, so we can rollover (after asking a keyserver) */
 
-	strcpy(nokeyrecipients,"");
+     strcpy(nokeyrecipients,"");
 
-	if (signFile == -1)
+     if (signFile == -1)
+     {
+	gettheKeys();
+	parseList(keyrecipients, nokeyrecipients);
+	action=menu_noyes(&signFile,&encryptFile,(strlen(nokeyrecipients)>3)); 
+	/* Menu 1 */
+	menu_noyes(&signFile,&encryptFile,(strlen(nokeyrecipients)>3));
+     }
+     else
+     {
+	if (encryptFile == -1)
 	{
-		gettheKeys();
-		parseList(keyrecipients, nokeyrecipients);
-	 	action=menu_noyes(&signFile,&encryptFile,(strlen(nokeyrecipients)>3)); 
-		/* Menu 1 */
-		menu_noyes(&signFile,&encryptFile,(strlen(nokeyrecipients)>3));
+	  if (signFile == 0) {
+	    documentStatus("Asking for sign\n");  
+            printf("You can sign this message. Do you want to:\n"
+	           "a) Send the message unmodified\n"
+                   "b) Sign this message\nq) Abort and quit\n\n");
+            switch (askAlphaRange("Make your choice ",'b','b','q'))
+            {
+      	      case 'a': action= 0; signFile = -1; documentStatus("Selection: S-\n"); break;
+    	      case 'b': action= 1; signFile =  1; documentStatus("Selection: S+\n"); break;
+    	      default : action=-1;                documentStatus("Selection: quit\n");
+            }
+  
+			
+	  }
 	}
 	else
-	{
-		if (encryptFile == -1)
-		{
-	 		if (signFile == 0)  signFile = askInteger("Do you want to sign this file/message? ",1);
-			if (signFile == -1) action=0; else action = 1; /* send or send and sign */
-		}
-		else
-		{	/* Now get the keys and then select a menu to present */
-			gettheKeys();
-			parseList(keyrecipients, nokeyrecipients);
-			if (signFile == 0)
-			{
-			  if (encryptFile == 0)
-			    menu = menu_askask;
-			  else
-			    menu = menu_askyes;
-			}
-			else
-			{
-			  if (encryptFile == 0)
-			    menu = menu_yesask;
-			  else
-			    menu = menu_yesyes;
-			}
-			action = menu(&signFile,&encryptFile,(strlen(nokeyrecipients)>3)); 
-			/* Let the menu decide what action to take. It does also manipulate 
-			   the s/e-choice from 0 to +/-1 */  
-		}	
-	}
-	/* Now we have decided what to do: send with some flags, ask server and rollover, or abort */
-	switch (action) 
-	{
-	  case 1: /* Send with flags */
-		/* Get the rest of the parameters */
-		useASCIIArmor = myUserPrefs->asciiArmor;
-		if (useASCIIArmor == 0) useASCIIArmor = askInteger("Do you want to use ASCII (RADIX-64) armoring? ", 1);
+	{	/* Now get the keys and then select a menu to present */
+	  gettheKeys();
+	  parseList(keyrecipients, nokeyrecipients);
+	  if (signFile == 0)
+	  {
+	    if (encryptFile == 0)
+	      menu = menu_askask;
+	    else
+	      menu = menu_askyes;
+	  }
+	  else
+	  {
+	    if (encryptFile == 0)
+	      menu = menu_yesask;
+	    else
+	      menu = menu_yesyes;
+	  }
+	  action = menu(&signFile,&encryptFile,(strlen(nokeyrecipients)>3)); 
+	  /* Let the menu decide what action to take. It does also manipulate 
+	     the s/e-choice from 0 to +/-1 */  
+        }       
+     }
+     /* Now we have decided what to do: send with some flags, ask server and rollover, or abort */
+     switch (action) 
+     {
+	case 1: /* Send with flags */
+	  /* Get the rest of the parameters */
+	  useASCIIArmor = myUserPrefs->asciiArmor;
+	  if (useASCIIArmor == 0) useASCIIArmor = askInteger("Do you want to use ASCII (RADIX-64) armoring? ", 1);
 
-		useUniversalText = myUserPrefs->universalText;	
-		if (useUniversalText == 0) useUniversalText = askInteger("Do you want to use canonical (universal) text formatting? ",1);
+	  useUniversalText = myUserPrefs->universalText;	
+	  if (useUniversalText == 0) useUniversalText = askInteger("Do you want to use canonical (universal) text formatting? ",1);
 
-		if (encryptFile > 0) 
-		{
-			myUserPrefs->detachedSig = -1; /* can't detach signature when encrypting... */
-			encryptToSelf = myUserPrefs->encryptToSelf;
-			if (encryptToSelf == 0) encryptToSelf = askInteger("Do you want to encrypt to yourself, too? ",1);
-		}
-		useDetachedSigs = myUserPrefs->detachedSig;
-		if (useDetachedSigs == 0) useDetachedSigs = askInteger("Do you want to use a detached signature?",-1);
+	  if (encryptFile > 0) 
+	  {
+	    myUserPrefs->detachedSig = -1; /* can't detach signature when encrypting... */
+	    encryptToSelf = myUserPrefs->encryptToSelf;
+	    if (encryptToSelf == 0) encryptToSelf = askInteger("Do you want to encrypt to yourself, too? ",1);
+	  }
+	  useDetachedSigs = myUserPrefs->detachedSig;
+	  if (useDetachedSigs == 0) useDetachedSigs = askInteger("Do you want to use a detached signature?",-1);
 
-		ret=fileSignEncrypt(inFile,outFile,signFile,encryptFile,keyrecipients,useASCIIArmor,useUniversalText,encryptToSelf,useDetachedSigs);
-		if (ret<0)
-		{
-		  fprintf(stderr,"Error while encrypting ! Aborting now.\n");
-		  return -1;
-		} else if (ret==1) {	/* fileSignEncrypt returned 'send unmodified' (failed to clearsign) */
-		  return 0;
-		} else if (ret==2) {	/* fileSignEncrypt returned 'return to Pine' (abort, but without error msg.) */
-		  return -1;
-		}
-		break;
-	  case 2: /* Ask server */
-		fileAskKey(nokeyrecipients);
-		/* Get the public keys again, as they have (hopefully) changed */
-		regetPublicKeyring();
-		break;
-	  case 3: /* Give me a shell */
-	  	runProcessFG("/bin/sh");
-		regetPublicKeyring();
-		break;
-	  case 0:  /* send unmodofied */
-/*	  	return 0; */
-		break;
-	  case -1: /* Abort message */
-/*	  	return -1; */
-		break;
-	  default: printf("Error: action=%d, menu selection went wrong !!\n",action);
-	}
+	  ret=fileSignEncrypt(inFile,outFile,signFile,encryptFile,keyrecipients,useASCIIArmor,useUniversalText,encryptToSelf,useDetachedSigs);
+	  if (ret<0)
+	  {
+	    fprintf(stderr,"Error while encrypting ! Aborting now.\n");
+	    return -1;
+	  } else if (ret==1) {	/* fileSignEncrypt returned 'send unmodified' (failed to clearsign) */
+	    return 0;
+	  } else if (ret==2) {	/* fileSignEncrypt returned 'return to Pine' (abort, but without error msg.) */
+	    return -1;
+	  }
+	  break;
+	case 2: /* Ask server */
+	  fileAskKey(nokeyrecipients,KEY_TOKENIZED);
+	  /* Get the public keys again, as they have (hopefully) changed */
+	  regetPublicKeyring();
+	  break;
+	case 3: /* Give me a shell */
+	  runProcessFG("/bin/sh");
+	  regetPublicKeyring();
+	  break;
+	case 0:  /* send unmodified */
+/*	  return 0; */
+	  break;
+	case -1: /* Abort message */
+/*	  return -1; */
+	  break;
+	default: printf("Error: action=%d, menu selection went wrong !!\n",action);
+     }
    } while ((action==2) || (action == 3)); /* repeat while we are adding keys */
    return action;	/* action is returnflag: -1,0,1 for abort, unmodified, modified */
 }
