@@ -106,8 +106,8 @@ int pipe_pgp2(const char *cmd, FILE **out, FILE **err)
 
 int fileVerify(const char *inFile,const char *outFile)
 {
-  char buf[500];
-  int  sigthere=0,fertig,dontprint;
+  char buf[500],KEY[500];
+  int  sigthere=0,fertig,dontprint,unknownsig=0;
   long endthere=0;
   char pgpAppString[MAX_COMMAND_LINE_LENGTH];
   int  c;
@@ -115,7 +115,7 @@ int fileVerify(const char *inFile,const char *outFile)
 
   /* Sometimes people manage to quote (part of) a signed mail WITHOUT using a quote sign,
      and cause us to be called here.
-     My experiments show the following:
+     My experiments show the following behaviour of PGP:
      (BEGIN always present, otherwise we aren't called):
 
      BEGIN present  SIGNATURE present  END present  action
@@ -124,7 +124,8 @@ int fileVerify(const char *inFile,const char *outFile)
   	   *		 -		     *       Error. No output.
   	   *		 -		     -       Error. No output.
 
-     Leading+trailing text is probably vital part of message text. */
+     Leading+trailing text is probably vital part of message text, 
+     so copy it to output. */
   
   documentStatus("pki.c\n\tfileVerify (inFile = '");
   documentStatus(inFile);
@@ -209,102 +210,128 @@ int fileVerify(const char *inFile,const char *outFile)
       if (buf[0]=='\n' || /* empty line */
         !strncmp(buf,"No files specified.",19) || /* PGP5 */
         !strncmp(buf,"Opening file",       12) || /* PGP5 */
+	!strncmp(buf,"Cannot open",        11) || /* PGP5 */
         !strncmp(buf,"gpg: Warn",           9))   /* GPG 'Warning' or 'Warnung' */
        dontprint=1;
       if (!dontprint) fputs(buf,outf);
+      if (strncmp(buf,"Signature by unknown",20)==0) {
+        char *tmp;
+        /* Got unknown signature. Extract & copy keyid to KEY */
+        unknownsig=1;
+	tmp = strtok (buf," ");
+        while (strncmp(tmp,"0x",2)) tmp = strtok('\0'," \n");
+        strncpy(KEY,tmp,20);
+      }
     }
   } while (!feof(pipeerr));
 
   fclose(outf); fclose(inf); fclose(pipeout); fclose(pipeerr);
+  if ((unknownsig) && (myUserPrefs->pgpVersion != 2)) {
+    if (prefsFetchUnknownSigs == 0) { /* Ask if we shall fetch sig key */
+      documentStatus("Signature by unknown key.\n");
+      printf("Signature by unknown key.\n a) Fetch key\n q) Don't mind\n");
+      if (askAlphaRange("Make your choice: ",'a','a','q') == 'q')
+        return 0;
+      else
+        prefsFetchUnknownSigs = 1;
+    }
+    if (prefsFetchUnknownSigs == 1) {
+      fileAskKey(KEY,KEY_HEX);
+      regetPublicKeyring();
+      prefsFetchUnknownSigs = -1; /* In case no key is found, no not try again */
+      return 1; /* Signal: Call me again */
+    }
+  }
+  return 0; 
 }
 
-/* ------------------------------------------------------------- */
-/* Decrypt an encrypted mail. Then put it in the cache, if we do */
-/* ------------------------------------------------------------- */
+/* ----------------------------------------------------------------- */
+/* Decrypt an encrypted mail. Then put it in the cache, if we should */
+/* ----------------------------------------------------------------- */
 
 void fileDecrypt(const char *inFile,const char *outFile)
 {
-	char pgpAppString[MAX_COMMAND_LINE_LENGTH];
-	int  ret;
+  char pgpAppString[MAX_COMMAND_LINE_LENGTH];
+  int  ret;
 
-	documentStatus("pki.c\n\tfileDecrypt (inFile = '");
-	documentStatus(inFile);
-	documentStatus("', outFile = '");
-	documentStatus(outFile);
-	documentStatus("')\n");
+  documentStatus("pki.c\n\tfileDecrypt (inFile = '");
+  documentStatus(inFile);
+  documentStatus("', outFile = '");
+  documentStatus(outFile);
+  documentStatus("')\n");
 
-	switch (myUserPrefs->pgpVersion) {
-	case 5:
-		sprintf(pgpAppString,"%s -o %s %s",myUserPrefs->pgp5pgpv,outFile,inFile);
-		break;
-	case 2:
-	case 6:
-		sprintf(pgpAppString,"%s %s -o %s",myUserPrefs->pgp2pgp,inFile,outFile);
-		break;
-	case 1:
-		sprintf(pgpAppString,"%s --no-greeting --output %s --decrypt %s",myUserPrefs->pgp1gpg,outFile,inFile);
-		break;	
-	}
-	documentStatus("\t\tpgpAppString = '");
-	documentStatus(pgpAppString);
-	documentStatus("'\n");
-	ret = runProcessFG(pgpAppString);
+  switch (myUserPrefs->pgpVersion) {
+  case 5:
+  	  sprintf(pgpAppString,"%s -o %s %s",myUserPrefs->pgp5pgpv,outFile,inFile);
+  	  break;
+  case 2:
+  case 6:
+  	  sprintf(pgpAppString,"%s %s -o %s",myUserPrefs->pgp2pgp,inFile,outFile);
+  	  break;
+  case 1:
+  	  sprintf(pgpAppString,"%s --no-greeting --output %s --decrypt %s",myUserPrefs->pgp1gpg,outFile,inFile);
+  	  break;  
+  }
+  documentStatus("\t\tpgpAppString = '");
+  documentStatus(pgpAppString);
+  documentStatus("'\n");
+  ret = runProcessFG(pgpAppString);
   if ((ret==0) && (prefsCacheDecrypted>0)) /* Cache the new file if decoded successful */
-	{
-	   struct stat stats;
-	   int  in,cache;
-	   u_int8_t *inbuf,b;
-	   u_int32_t date;
-	   u_int32_t size;
-	   MD5_CONTEXT ctx;
-	   char tmpString[35];
-	   
-	   /* If anything goes wrong, just don't cache */
-	   if ((in = open(inFile,O_RDONLY))<0) return;
-	   if (fstat(in,&stats)<0) return;	/* stat for size */
-	   if (stats.st_size==0) return;
-	   
-	   /* Map file to memory */
-	   if ((inbuf = (u_int8_t *)mmap(0,stats.st_size, PROT_READ, MAP_SHARED,in,0))
-	       == (u_int8_t *) -1) { close(in); return; }
-	   /* Create a md5 sum to identify it later */
-	   md5_init(&ctx);
-	   md5_write(&ctx, inbuf, stats.st_size);
-	   md5_final(&ctx);
-	   munmap(inbuf, stats.st_size);
-	   close(in); 
+  {
+    struct stat stats;
+    int  in,cache;
+    u_int8_t *inbuf,b;
+    u_int32_t date;
+    u_int32_t size;
+    MD5_CONTEXT ctx;
+    char tmpString[35];
+    
+    /* If anything goes wrong, just don't cache */
+    if ((in = open(inFile,O_RDONLY))<0) return;
+    if (fstat(in,&stats)<0) return;	 /* stat for size */
+    if (stats.st_size==0) return;
+    
+    /* Map file to memory */
+    if ((inbuf = (u_int8_t *)mmap(0,stats.st_size, PROT_READ, MAP_SHARED,in,0))
+ 	== (u_int8_t *) -1) { close(in); return; }
+    /* Create a md5 sum to identify it later */
+    md5_init(&ctx);
+    md5_write(&ctx, inbuf, stats.st_size);
+    md5_final(&ctx);
+    munmap(inbuf, stats.st_size);
+    close(in); 
 
-	   if ((in = open(outFile,O_RDONLY))<0) return;
-	   if (fstat(in,&stats)<0) return;
-	   if ((inbuf = (u_int8_t *)mmap(0,stats.st_size, PROT_READ, MAP_PRIVATE,in,0))
-	       == (u_int8_t *) -1) { close(in); return; }
-	 
-	   /* and create the cache entry */
-	   documentStatus("Creating cache entry MD5: ");
-	   sprintf(tmpString,"%x%x%x%x%x%x%x%x %x%x%x%x%x%x%x%x\n",
- 		ctx.buf[0],ctx.buf[1],ctx.buf[2],ctx.buf[3],
-		ctx.buf[4],ctx.buf[5],ctx.buf[6],ctx.buf[7],
-		ctx.buf[8],ctx.buf[9],ctx.buf[10],ctx.buf[11],
-		ctx.buf[12],ctx.buf[13],ctx.buf[14],ctx.buf[15]);
-	   documentStatus(tmpString);
-	   if ((cache = open(DecryptCacheName,O_WRONLY|O_CREAT|O_APPEND,0600))<0) return;
+    if ((in = open(outFile,O_RDONLY))<0) return;
+    if (fstat(in,&stats)<0) return;
+    if ((inbuf = (u_int8_t *)mmap(0,stats.st_size, PROT_READ, MAP_PRIVATE,in,0))
+ 	== (u_int8_t *) -1) { close(in); return; }
+  
+    /* and create the cache entry */
+    documentStatus("Creating cache entry MD5: ");
+    sprintf(tmpString,"%x%x%x%x%x%x%x%x %x%x%x%x%x%x%x%x\n",
+ 	 ctx.buf[0],ctx.buf[1],ctx.buf[2],ctx.buf[3],
+ 	 ctx.buf[4],ctx.buf[5],ctx.buf[6],ctx.buf[7],
+ 	 ctx.buf[8],ctx.buf[9],ctx.buf[10],ctx.buf[11],
+ 	 ctx.buf[12],ctx.buf[13],ctx.buf[14],ctx.buf[15]);
+    documentStatus(tmpString);
+    if ((cache = open(DecryptCacheName,O_WRONLY|O_CREAT|O_APPEND,0600))<0) return;
 
-	   write(cache,"\x12\x34",2); /* magic 0x1234 */
-	   size = stats.st_size+cacheHeaderSize;
-	   size = to_bigend_u32(size);
-	   write(cache,&size,4);                /* size */
-	   b=CACHE_VERSION; write(cache,&b,1);  /* version */
-	   b=0;             write(cache,&b,1);  /* Characterize as message entry */
-	   write(cache,ctx.buf,16);             /* MD5 */
-	   date = (time(0)/60);                 /* minute resolution */
-	   date = to_bigend_u32(date);
-	   write(cache,&date,4);
-	   write(cache,"  ",2);			/* Two dummy bytes (unused) */
-	   write(cache, inbuf, stats.st_size);
-	   close(cache);
-	   munmap(inbuf, stats.st_size);
-	   close(in);
-	}
+    write(cache,"\x12\x34",2); /* magic 0x1234 */
+    size = stats.st_size+cacheHeaderSize;
+    size = to_bigend_u32(size);
+    write(cache,&size,4);		 /* size */
+    b=CACHE_VERSION; write(cache,&b,1);  /* version */
+    b=0;	     write(cache,&b,1);  /* Characterize as message entry */
+    write(cache,ctx.buf,16);		 /* MD5 */
+    date = (time(0)/60);		 /* minute resolution */
+    date = to_bigend_u32(date);
+    write(cache,&date,4);
+    write(cache,"  ",2);		 /* Two dummy bytes (unused) */
+    write(cache, inbuf, stats.st_size);
+    close(cache);
+    munmap(inbuf, stats.st_size);
+    close(in);
+  }
 }
 
 /* ------------------------------------------ */
@@ -552,7 +579,17 @@ int fileSignEncrypt(const char *inFileName,
 	case 1:
 		if (myUserPrefs->asciiArmor > 0) strcat(pgpOptions, " -a ");
 		if (myUserPrefs->universalText > 0) strcat(pgpOptions, " -t ");
+		if ((strlen(mySecretKey) > 3) && (sign > 0)) {
+				strcat(pgpOptions," -u \"");
+				strcat(pgpOptions,mySecretKey);
+				strcat(pgpOptions,"\" ");
+		}
+		if (prefsAddComment > 0) 
+			commentString = "--comment \"Made with pgp4pine " VERSION "\"";
+		else
+			commentString = "";
 
+		/* End of options */
 		if (encrypt > 0) {
 			strcat(pgpOptions," -e ");
 			strcpy(recipList,recipient);
@@ -561,18 +598,9 @@ int fileSignEncrypt(const char *inFileName,
 			if (detachSigs > 0) strcat(pgpOptions," -b ");
 			strcat(pgpOptions," -s ");
 			if (encrypt == 0) strcat(pgpOptions," --clearsign ");
-			if (strlen(mySecretKey) > 3) {
-				strcat(pgpOptions," -u \"");
-				strcat(pgpOptions,mySecretKey);
-				strcat(pgpOptions,"\" ");
-			}
 		}
 		/* if we're not encrypting, recipList is just a " ", so we're safe... */
 		/* Just moved outfilename to begining of list per email from henrik kg andreasson */
-		if (prefsAddComment > 0) 
-			commentString = "--comment \"Made with pgp4pine " VERSION "\"";
-		else
-			commentString = "";
 			
 		sprintf(pgpAppString,"%s -o %s --no-batch %s --no-greeting %s %s %s",
 		    myUserPrefs->pgp1gpg,outFileName,commentString,recipList,pgpOptions,inFileName);
@@ -611,11 +639,12 @@ int fileSignEncrypt(const char *inFileName,
 	return exitcode;
 }
 
-/* ------------------------------------- */
-/* Get unknown keys from keyserver       */
-/* ------------------------------------- */
+/* ---------------------------------------------------------- */
+/* Get unknown keys from keyserver                            */
+/* Parameter is space-separated list of keys, last one is '.' */
+/* ---------------------------------------------------------- */
 
-void fileAskKey(char *nokeyrecipients)
+void fileAskKey(char *nokeyrecipients,int MODE)
 {
 	char pgpAppString[MAX_COMMAND_LINE_LENGTH];
 	char tmpEmail[EMAIL_ADDRESS_MAX_LENGTH];
@@ -626,7 +655,7 @@ void fileAskKey(char *nokeyrecipients)
 	} else {
 	  documentStatus("Asking Keyserver for unknown keys");
 	
-	  do {
+	  if (MODE==KEY_TOKENIZED) do {
 		if (i==0) strcpy(tmpEmail,strtok(nokeyrecipients," "));
 		else strcpy(tmpEmail,strtok('\0'," "));
 		if (strcmp(tmpEmail,".")) {
@@ -643,6 +672,15 @@ void fileAskKey(char *nokeyrecipients)
 		}
 		i++;
 	  } while(strcmp(tmpEmail,"."));
+	  else if (strlen(nokeyrecipients)>1) { /* MODE==KEY_HEX */
+ 	    if (myUserPrefs->pgpVersion == 5)
+ 	      sprintf(pgpAppString,"%s -a %s",myUserPrefs->pgp5pgpk,nokeyrecipients);
+ 	    else
+ 	      sprintf(pgpAppString,"%s --recv-keys %s",myUserPrefs->pgp1gpg,nokeyrecipients);
+
+ 	    documentStatus(pgpAppString);
+ 	    runProcessFG(pgpAppString);   
+	  }
 	}
 }
 
