@@ -97,9 +97,6 @@ void readRCFile()
 	    strcat(DecryptCacheName,"/.pgp4pine.cache");
 	}
 
-	a = readPrefs("override_recipients","0");
-	prefsOverrideRecipients = atoi(a);
-	
 	a = readPrefs("extra_enter_at_end","0");
 	prefsExtraCRLFAtEnd = atoi(a);
 	
@@ -115,6 +112,12 @@ void readRCFile()
 	  a = readPrefs("cache_decrypted","0");
 	  prefsCacheDecrypted = parseTime(a);   /* Parse a time entry: 5 min, 1 day */
 	  a = readPrefs("cache_keyrings","1 day");
-	  prefsCacheDecrypted = parseTime(a);   /* Parse a time entry: 5 min, 1 day */
-	} else prefsCacheDecrypted=-1;
+	  prefsCacheKeyrings = parseTime(a);   /* Parse a time entry: 5 min, 1 day */
+	} else { 
+	  prefsCacheDecrypted= -1; 
+	  prefsCacheKeyrings = -1; 
+	}
+	
+	a = readPrefs("keyserver_on_sig","0");
+	prefsFetchUnknownSigs = atoi(a);
 }
