@@ -67,9 +67,13 @@ void selectProfile()
 
 		sprintf(tmpString,"profile_%s_autosign",thisProfileName);
 		thisProfile->autoSign = atoi(readPrefs(tmpString,"0"));
+		if (thisProfile->autoSign > 1) thisProfile->autoSign = 1;
+		if (thisProfile->autoSign <-1) thisProfile->autoSign =-1;
 
 		sprintf(tmpString,"profile_%s_autoencrypt",thisProfileName);
 		thisProfile->autoEncrypt = atoi(readPrefs(tmpString,"0"));
+		if (thisProfile->autoEncrypt > 1) thisProfile->autoEncrypt = 1;
+		if (thisProfile->autoEncrypt <-1) thisProfile->autoEncrypt =-1;
 
 		sprintf(tmpString,"profile_%s_my_address",thisProfileName);
 		strcpy(thisProfile->myAddress,readPrefs(tmpString," "));
