@@ -22,7 +22,7 @@ struct pkiKey {
 
 struct myProfile {
 	char profileName[254];
-	int pgpVersion; // see pki.c for values
+	int pgpVersion; /* see pki.c for values */
 	char extraOptions[MAX_COMMAND_LINE_LENGTH]; 
 	int autoSign;	
 	int autoEncrypt;
@@ -31,7 +31,7 @@ struct myProfile {
 	int asciiArmor;
 	int universalText;
 	char myTmpFile[MAX_COMMAND_LINE_LENGTH];
-		// set to anything less than strlen(3) to turn off.
+		/* set to anything less than strlen(3) to turn off. */
 	struct myProfile *nextProfile;
 	int detachedSig;
 	char pgp5pgpk[MAX_COMMAND_LINE_LENGTH];
@@ -40,7 +40,19 @@ struct myProfile {
 	char pgp5pgpv[MAX_COMMAND_LINE_LENGTH];
 	char pgp2pgp[MAX_COMMAND_LINE_LENGTH];
 	char pgp1gpg[MAX_COMMAND_LINE_LENGTH];
+	char pubringfile[MAX_COMMAND_LINE_LENGTH]; /* Not used yet! */
+	char secringfile[MAX_COMMAND_LINE_LENGTH];
 } myProfileStruct;
 
+#define cacheHeaderSize 30
+/* struct cache_Entry {
+	u_int16_t  magic;     #0,1     = 0x1234 for structure integrity
+	u_int32_t  size;      #2,3,4,5 size header plus message
+	u_int16_t  version;   #6       header version
+	u_int8_t   type;      #7       Entry type. 0:Msg., 1: PubKeys, 2: SecKeys
+	u_int8_t   md5[16];   #8..23   MD5 sum(msg) or profile name(keys)
+	u_int32_t  date;      #24,25,26,27 date (minutes since 1970)
+	u_int16_t  numentries #28,29  Number of entries (only Keyrings)
+}; */
 #endif
 
